@@ -1,7 +1,7 @@
 """ This module provides the project version info and comparison utility.
     """
 
-__version_info__ = (0, 1, 0)
+__version_info__ = (0, 1, 1)
 __version__ = '.'.join(str(x) for x in __version_info__)
 
 
@@ -10,7 +10,7 @@ def compare_version(value):
 
         `value`
             Version comparison string (e.g. ==1.0, <=1.0, >1.1)
-                Supported operatorators:
+                Supported operators:
                     <, <=, ==, >, >=
         """
 
